==> OpenCL-0.8.3.tgz: OpenCL-0.8.3/src/emsa2.cpp <==
/*************************************************
* EMSA2 Source File                              *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/emsa2.h>
#include <opencl/ieee1363.h>

namespace OpenCL {

/*************************************************
* EMSA2 Encode Operation                         *
*************************************************/
SecureVector<byte> EMSA2::encode_op(const byte msg[], u32bit msg_len,
                                    u32bit output_length) const
   {
   output_length = (output_length + 1) / 8;

   if(msg_len != HASH_OUTPUT_LENGTH)
      throw Invalid_Argument("EMSA2::pad: Bad input length");
   if(output_length < HASH_OUTPUT_LENGTH + 4)
      throw Invalid_Argument("EMSA2::pad: Output length is too small");

   bool empty = true;
   for(u32bit j = 0; j != HASH_OUTPUT_LENGTH; j++)
      if(empty_hash[j] != msg[j])
         empty = false;

   SecureVector<byte> output(output_length);

   output[0] = (empty ? 0x4B : 0x6B);
   output[output_length - 3 - HASH_OUTPUT_LENGTH] = 0xBA;
   set_mem(output + 1, output_length - 4 - HASH_OUTPUT_LENGTH, 0xBB);
   output.copy(output_length-2-HASH_OUTPUT_LENGTH, msg, HASH_OUTPUT_LENGTH);
   output[output_length-2] = hash_id;
   output[output_length-1] = 0xCC;

   return output;
   }

/*************************************************
* EMSA2 Constructor                              *
*************************************************/
EMSA2::EMSA2(HashFunction* hash) : HASH_OUTPUT_LENGTH(hash->OUTPUT_LENGTH)
   {
   hash_id = ieee1363_hash_id(hash);
   if(hash_id == 0)
      throw Invalid_Argument("EMSA2 cannot be used with " + hash->name());
   empty_hash = hash->final();
   delete hash;
   }

}

==> OpenCL-0.8.4.tgz: OpenCL-0.8.4/src/emsa2.cpp <==
/*************************************************
* EMSA2 Source File                              *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/emsa2.h>
#include <opencl/ieee1363.h>

namespace OpenCL {

/*************************************************
* EMSA2 Encode Operation                         *
*************************************************/
SecureVector<byte> EMSA2::encode_op(const byte msg[], u32bit msg_len,
                                    u32bit output_length) const
   {
   output_length = (output_length + 1) / 8;

   if(msg_len != HASH_OUTPUT_LENGTH)
      throw Invalid_Argument("EMSA2::pad: Bad input length");
   if(output_length < HASH_OUTPUT_LENGTH + 4)
      throw Invalid_Argument("EMSA2::pad: Output length is too small");

   bool empty = true;
   for(u32bit j = 0; j != HASH_OUTPUT_LENGTH; j++)
      if(empty_hash[j] != msg[j])
         empty = false;

   SecureVector<byte> output(output_length);

   output[0] = (empty ? 0x4B : 0x6B);
   output[output_length - 3 - HASH_OUTPUT_LENGTH] = 0xBA;
   set_mem(output + 1, output_length - 4 - HASH_OUTPUT_LENGTH, 0xBB);
   output.copy(output_length-2-HASH_OUTPUT_LENGTH, msg, HASH_OUTPUT_LENGTH);
   output[output_length-2] = hash_id;
   output[output_length-1] = 0xCC;

   return output;
   }

/*************************************************
* EMSA2 Constructor                              *
*************************************************/
EMSA2::EMSA2(const std::string& hash_name) :
   HASH_OUTPUT_LENGTH(output_length_of(hash_name))
   {
   HashFunction* hash = get_hash(hash_name);
   hash_id = ieee1363_hash_id(hash_name);
   if(hash_id == 0)
      throw Invalid_Argument("EMSA2 cannot be used with " + hash->name());
   empty_hash = hash->final();
   delete hash;
   }

/*************************************************
* EMSA2 Constructor                              *
*************************************************/
EMSA2::EMSA2(HashFunction* hash) : HASH_OUTPUT_LENGTH(hash->OUTPUT_LENGTH)
   {
   hash_id = ieee1363_hash_id(hash->name());
   if(hash_id == 0)
      throw Invalid_Argument("EMSA2 cannot be used with " + hash->name());
   empty_hash = hash->final();
   delete hash;
   }

}
